"""Sound utilities."""

import os
import sys
from subprocess import call


def playaudio(file: str) -> None:
    assert os.path.exists(file), f"Sound file {file} does not exist."
    if sys.platform != "win32":
        if "linux" in sys.platform:
            call(["xdg-open", file])
        elif sys.platform == "darwin":
            call(["afplay", file])
        else:
            assert False, f"Unsupported platform: {sys.platform}."
        return
    import winsound  # type: ignore  # pylint: disable=all

    winsound.PlaySound(file, winsound.SND_FILENAME)



"""
Main entry point.
"""

import argparse
from playaudio import playaudio

from playaudio.assets.builtin import BELL_FILE


def main() -> int:
    """Main entry point for the playaudio package."""
    parser = argparse.ArgumentParser("playaudio")
    parser.add_argument("file", help="Sound file to play.", nargs="?")
    args = parser.parse_args()
    file = args.file if args.file else BELL_FILE
    playaudio(file)
    return 0



import os
import re

import setuptools

URL = "https://github.com/zackees/playaudio"

HERE = os.path.dirname(os.path.abspath(__file__))


def get_readme() -> str:
    """Get the contents of the README file."""
    readme = os.path.join(HERE, "README.md")
    with open(readme, encoding="utf-8", mode="r") as readme_file:
        readme_lines = readme_file.readlines()
    for i, line in enumerate(readme_lines):
        if "../../" in line:
            # Transform the relative links to absolute links
            output_string = re.sub(r"(\.\./\.\.)", f"{URL}", line, count=1)
            output_string = re.sub(r"(\.\./\.\.)", f"{URL}", output_string)
            readme_lines[i] = output_string
    return "".join(readme_lines)


if __name__ == "__main__":
    setuptools.setup(
        long_description=get_readme(),
        long_description_content_type="text/markdown",
        url=URL,
        package_data={"": ["assets/example.txt"]},
        include_package_data=True,
    )
